#!perl -T

use Test::More tests => 1;

BEGIN {
	use_ok( 'HTML::FormatText::WithLinks::AndTables' );
}

diag( "Testing HTML::FormatText::WithLinks::AndTables $HTML::FormatText::WithLinks::AndTables::VERSION, Perl $], $^X" );
